==> ejc-zatopbpm-impl-3.0.0-20231012.032030-70-sources.jar: com/ejianc/business/bidprice/MaterialPicketageZatopbpmServiceImpl.java <==
package com.ejianc.business.bidprice;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.ejianc.business.common.CommonZatopDataDealService;
import com.ejianc.business.consts.ZatopConstsUtil;
import com.ejianc.zatopbpm.service.common.ICommonZatopBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

@Service("ejc-bidprice-web-materialPicketageZatop")
public class MaterialPicketageZatopbpmServiceImpl extends CommonZatopDataDealService implements ICommonZatopBusinessService {

    private final Logger logger = LoggerFactory.getLogger(getClass());

    /**
     * 数据单独处理
     *
     * @param billId
     * @param billData 单据信息---从数据库中查询出来的信息
     * @return billData需要将单据信息+处理的信息返回
     */
    @Override
    public JSONObject dealBillData(Long billId, JSONObject billData) {
        billData.put("pricingType", ZatopConstsUtil.getPricingTypeName(billData.getString("pricingType")));
        String purchaseMode = billData.getString("purchaseMode");
        purchaseMode = "1".equals(purchaseMode) ? "2" : "1";
        billData.put("purchaseType", ZatopConstsUtil.getPurchaseModeName(purchaseMode));
        logger.info("{}-billData:{}", getClass().getName(), JSON.toJSONString(billData, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
        return billData;
    }

    /**
     * 主表添加额外的表单中的字段
     *
     * @param billId
     * @param fields 主表信息集合---经过处理后的
     * @return fields 推送给第三方的最后数据,按格式返回
     * @return"fields": [
     *  {
     *  "id": "TITLE",
     *  "name": "流程主题",
     *  "value": "XXX 项目合同流程",
     *  "modifyStatus": ""
     *  },
     *  {
     *  "id": "ContractName",
     *  "name": "合同名称",
     *  "value": "XXX 项目合同",
     *  "modifyStatus": ""
     *  }
     *  ]
     */
    public JSONArray addFields(Long billId, JSONObject billData, JSONArray fields) {
        return addFieldsForBillData(billId, billData, fields);
    }

    /**
     * 子表数据库数据单独处理----子表多个时会遍历循环此方法
     *
     * @param billId
     * @param entityName 子表实体名
     * @param childrenData 单据子表信息---从数据库中查询出来的信息，一个子表的
     * @return billData需要将单据信息+处理的信息返回
     * @return
     */
    public JSONArray dealBillchldrenData(Long billId, String entityName, JSONArray childrenData) {
        return childrenData;
    }

    /**
     * 子表数据单独处理
     *
     * @param billId
     * @param lists  子表信息集合---经过处理后的
     * @return lists 推送给第三方的最后数据,按格式返回
     * @return "lists": [[
     * {
     * "listId": "ContractPaymentDetail",
     * "listName": "合同付款比例明细",
     * "items": [
     * {
     * "id": "FKBL",
     * "name": "付款比例",
     * "value": "30%",
     * "modifyStatus": ""
     * },
     * {
     * "id": "FKBL",
     * "name": "付款比例",
     * "value": "30%",
     * "modifyStatus": ""
     * },
     * {
     * "id": "FKBL",
     * "name": "付款比例",
     * "value": "30%",
     * "modifyStatus": ""
     * }
     * ]
     * }
     * ]]]
     */
    @Override
    public JSONArray dealBillChildrenData(Long billId, JSONArray lists) {
        return lists;
    }

    /**
     * 主表数据单独处理
     *
     * @param billId
     * @param sourceType 附件类型
     * @param attachments 单据附件信息---经过处理后的
     * @return attachments 推送给第三方的最后数据,按格式返回
     * @return "attachments": [
     * {
     * "fileId": "92535855-A661-E911-80BD-90E2BABD62D1",
     * "fileName": "【打印 3 份】南京公司-璞樾钟山-大区除 24 号楼家用除霾新风设备采购合同.docx",
     * "fileType": "合同登记",
     * "fileUrl": "http:/",
     * "uploadUserId":"kook.zhang",
     * "uploadUserName":"张亮",
     * "modifyStatus":""
     * }]
     */
    @Override
    public JSONArray dealBillAttachmentsData(Long billId, String billTypeCode, String sourceType, JSONArray attachments) {
        return attachments;
    }

}

==> ejc-zatopbpm-impl-3.0.0-20231013.091503-77-sources.jar: com/ejianc/business/bidprice/MaterialPicketageZatopbpmServiceImpl.java <==
package com.ejianc.business.bidprice;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.ejianc.business.common.CommonZatopDataDealService;
import com.ejianc.business.consts.ZatopConstsUtil;
import com.ejianc.zatopbpm.service.common.ICommonZatopBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;

@Service("ejc-bidprice-web-materialPicketageZatop")
public class MaterialPicketageZatopbpmServiceImpl extends CommonZatopDataDealService implements ICommonZatopBusinessService {

    private final Logger logger = LoggerFactory.getLogger(getClass());

    /**
     * 数据单独处理
     *
     * @param billId
     * @param billData 单据信息---从数据库中查询出来的信息
     * @return billData需要将单据信息+处理的信息返回
     */
    @Override
    public JSONObject dealBillData(Long billId, JSONObject billData) {
        logger.info("{}-billData11:{}", getClass().getName(), JSON.toJSONString(billData, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));

        billData.put("pricingType", ZatopConstsUtil.getPricingTypeName(billData.getString("pricingType")));
        String purchaseType = billData.getString("purchaseType");
        purchaseType = "1".equals(purchaseType) ? "2" : "1";
        String quotationAuthority = billData.getString("quotationAuthority");
        billData.put("purchaseType", ZatopConstsUtil.getPurchaseModeName(purchaseType));
        //quotationAuthority
        billData.put("quotationAuthority", ZatopConstsUtil.getQuotationAuthorityName(quotationAuthority));
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        billData.put("handleDate",sdf.format( billData.getDate("handleDate")));
        logger.info("{}-billData:{}", getClass().getName(), JSON.toJSONString(billData, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
        return billData;
    }

    /**
     * 主表添加额外的表单中的字段
     *
     * @param billId
     * @param fields 主表信息集合---经过处理后的
     * @return fields 推送给第三方的最后数据,按格式返回
     * @return"fields": [
     *  {
     *  "id": "TITLE",
     *  "name": "流程主题",
     *  "value": "XXX 项目合同流程",
     *  "modifyStatus": ""
     *  },
     *  {
     *  "id": "ContractName",
     *  "name": "合同名称",
     *  "value": "XXX 项目合同",
     *  "modifyStatus": ""
     *  }
     *  ]
     */
    public JSONArray addFields(Long billId, JSONObject billData, JSONArray fields) {
        return addFieldsForBillData(billId, billData, fields);
    }

    /**
     * 子表数据库数据单独处理----子表多个时会遍历循环此方法
     *
     * @param billId
     * @param entityName 子表实体名
     * @param childrenData 单据子表信息---从数据库中查询出来的信息，一个子表的
     * @return billData需要将单据信息+处理的信息返回
     * @return
     */
    public JSONArray dealBillchldrenData(Long billId, String entityName, JSONArray childrenData) {
        if (entityName.contains("MaterialPicketageQuoteEntity")) {
            if (childrenData != null && childrenData.size() > 0) {
                for (int i = 0; i < childrenData.size(); i++) {
                    JSONObject obj = childrenData.getJSONObject(i);
                    String bidFlag = obj.getString("bidFlag");
                    bidFlag = "1".equals(bidFlag) ? "是" : "否";
                    obj.put("bidFlag",bidFlag );
                }
            }
        }
        return childrenData;
    }

    /**
     * 子表数据单独处理
     *
     * @param billId
     * @param lists  子表信息集合---经过处理后的
     * @return lists 推送给第三方的最后数据,按格式返回
     * @return "lists": [[
     * {
     * "listId": "ContractPaymentDetail",
     * "listName": "合同付款比例明细",
     * "items": [
     * {
     * "id": "FKBL",
     * "name": "付款比例",
     * "value": "30%",
     * "modifyStatus": ""
     * },
     * {
     * "id": "FKBL",
     * "name": "付款比例",
     * "value": "30%",
     * "modifyStatus": ""
     * },
     * {
     * "id": "FKBL",
     * "name": "付款比例",
     * "value": "30%",
     * "modifyStatus": ""
     * }
     * ]
     * }
     * ]]]
     */
    @Override
    public JSONArray dealBillChildrenData(Long billId, JSONArray lists) {
        return lists;
    }

    /**
     * 主表数据单独处理
     *
     * @param billId
     * @param sourceType 附件类型
     * @param attachments 单据附件信息---经过处理后的
     * @return attachments 推送给第三方的最后数据,按格式返回
     * @return "attachments": [
     * {
     * "fileId": "92535855-A661-E911-80BD-90E2BABD62D1",
     * "fileName": "【打印 3 份】南京公司-璞樾钟山-大区除 24 号楼家用除霾新风设备采购合同.docx",
     * "fileType": "合同登记",
     * "fileUrl": "http:/",
     * "uploadUserId":"kook.zhang",
     * "uploadUserName":"张亮",
     * "modifyStatus":""
     * }]
     */
    @Override
    public JSONArray dealBillAttachmentsData(Long billId, String billTypeCode, String sourceType, JSONArray attachments) {
        return attachments;
    }

}
